@@ -15,6 +15,7 @@
 from mkdocs.plugins import BasePlugin
 from .parser import Parser
 from .merger import Merger
+from .edit_uri import set_edit_url
 
 
 class MonorepoPlugin(BasePlugin):
@@ -44,7 +45,9 @@ class MonorepoPlugin(BasePlugin):
 
         # Generate a new "docs" directory
         self.merger = Merger(config)
+        self.aliases = {}
         for alias, docs_dir, yaml_file in resolvedPaths:
+            self.aliases[alias] = { 'docs_dir': docs_dir, 'yaml_file': yaml_file }
             self.merger.append(alias, docs_dir)
         new_docs_dir = self.merger.merge()
 
@@ -65,6 +68,7 @@ class MonorepoPlugin(BasePlugin):
         if len(self.files_source_dir) > 0:
             if page.file.abs_src_path in self.files_source_dir:
                 page.file.abs_src_path = self.files_source_dir[page.file.abs_src_path]
+                set_edit_url(config, page, self)
         return page
 
     def on_serve(self, server, config, **kwargs):
